@@ -43,33 +43,35 @@ FILE * debugfile;
 #define DEBUG_FILENAME "/tmp/gsysinfo_debug"
 #endif
 
+GSysInfoData * gd;
+
 a_color AppColors[NUM_COLORS] = {
     // colors for load average bar
-    { "loadavgbar0", "#FFA0A0", 0 },	// RosyBrown1
-    { "loadavgbar1", "#FF6A6A", 0 },	// IndianRed1
-    { "loadavgbar2", "#FF4500", 0 },	// OrangeRed1
-    { "loadavgbar3", "#FF3838", 0 },	// firebrick1
-    { "loadavgbar4", "#FFB5C5", 0 },	// pink1
-    { "loadavgbar5", "#FF6EB4", 0 },	// HotPink1
-    { "loadavgbar6", "#FF1493", 0 },	// DeepPink2
-    { "loadavgbar7", "#B03060", 0 },	// maroon1
+    { "Load Average 0", "loadavg0", "#FFA0A0", 0 },	// RosyBrown1
+    { "Load Average 1", "loadavg1", "#FF6A6A", 0 },	// IndianRed1
+    { "Load Average 2", "loadavg2", "#FF4500", 0 },	// OrangeRed1
+    { "Load Average 3", "loadavg3", "#FF3838", 0 },	// firebrick1
+    { "Load Average 4", "loadavg4", "#FFB5C5", 0 },	// pink1
+    { "Load Average 5", "loadavg5", "#FF6EB4", 0 },	// HotPink1
+    { "Load Average 6", "loadavg6", "#FF1493", 0 },	// DeepPink2
+    { "Load Average 7", "loadavg7", "#fcc1ff", 0 },	// light purple
+    { "Load Average 8", "loadavg8", "#caadff", 0 },	// pastel darker pruple
+    { "Load Average 9", "loadavg9", "#c2e1ff", 0 },	// pastel blue
 
     // colors for current load bar
-    { "loadbar", "#00EEEE", 0 },   // cyan2
-    { "loadbar1", "#5CACEE", 0 },  // SteelBlue2
-    { "loadbar2", "#0000FF", 0 },  // blue
+    { "User CPU", "usercpu", "#00EEEE", 0 },   // cyan2
+    { "System CPU", "systemcpu", "#5CACEE", 0 },  // SteelBlue2
+    { "Nice CPU", "nicecpu", "#0000FF", 0 },  // blue
 
     // colors for memory bar
-    { "membar", "#00EE00", 0 },    // green2
-    { "membar1", "#008B00", 0 },   // green4
+    { "Normal Mem", "normalmem", "#00EE00", 0 },    // green2
+    { "Buffers/Cached Mem", "buffermem", "#008B00", 0 },   // green4
 
     // colors for swap space bar
-    { "swapbar", "#FF6EB4", 0 },   // hotpink1
-    { "swapbar1", "#CD6090", 0 },  // hotpink3
-    { "swapbar2", "#8B3A62", 0 },  // hotpink4
+    { "Swap Used", "swap", "#FF6EB4", 0 },   // hotpink1
 
     // bar background color
-    { "bargauge_bg", "#FFFFFF", 0 }	// white
+    { "Background", "background", "#FFFFFF", 0 }	// white
 };
 
 
@@ -129,30 +131,39 @@ void draw_border( GSysInfoData * gd, int x1, int y1, int x2, int y2 )
   GtkStyle *	style;
 
   style = gtk_widget_get_style( gd->applet );
-  gdk_draw_line( gd->pixmap, style->dark_gc[0], x1, y1, x2, y1 );
-  gdk_draw_line( gd->pixmap, style->dark_gc[0], x1, y1, x1, y2 );
-  gdk_draw_line( gd->pixmap, style->black_gc, x1 + 1, y1 + 1, x2 - 1, y1 + 1 );
-  gdk_draw_line( gd->pixmap, style->black_gc, x1 + 1, y1 + 1, x1 + 1, y2 - 1 );
 
-  gdk_draw_line( gd->pixmap, style->white_gc, x1 + 1, y2, x2, y2 );
-  gdk_draw_line( gd->pixmap, style->white_gc, x2, y2, x2, y1 + 1 );
-  gdk_draw_line( gd->pixmap, style->mid_gc[0], x1 + 2, y2 - 1, x2 - 1, y2 - 1 );
-  gdk_draw_line( gd->pixmap, style->mid_gc[0], x2 - 1, y2 - 1, x2 - 1, y1 + 2 );
+  //gtk_draw_shadow( gtk_widget_get_style( gd->applet ),
+		   //GTK_WIDGET( gd->applet )->window,	
+		   //GTK_STATE_NORMAL,
+		   //GTK_SHADOW_IN,
+		   //x1, y1, x2 - x1 + 1, y2 - y1 + 1 );
+  
+  //gdk_draw_line( gd->pixmap, style->dark_gc[0], x1, y1, x2, y1 );
+  //gdk_draw_line( gd->pixmap, style->dark_gc[0], x1, y1, x1, y2 );
+  //gdk_draw_line( gd->pixmap, style->black_gc, x1 + 1, y1 + 1, x2 - 1, y1 + 1 );
+  //gdk_draw_line( gd->pixmap, style->black_gc, x1 + 1, y1 + 1, x1 + 1, y2 - 1 );
+
+  //gdk_draw_line( gd->pixmap, style->white_gc, x1 + 1, y2, x2, y2 );
+  //gdk_draw_line( gd->pixmap, style->white_gc, x2, y2, x2, y1 + 1 );
+  //gdk_draw_line( gd->pixmap, style->mid_gc[0], x1 + 2, y2 - 1, x2 - 1, y2 - 1 );
+  //gdk_draw_line( gd->pixmap, style->mid_gc[0], x2 - 1, y2 - 1, x2 - 1, y1 + 2 );
 }
 
 // barx, bary, bar_breadth, and bar_depth have already been corrected for the 
 // size of the border bevelling
-void draw_loadavg( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_depth ) {
+void draw_loadavg( GSysInfoData * gd, 
+		   int barx, 
+		   int bary, 
+		   int bar_breadth, 
+		   int bar_depth ) {
 
-  double loadavg;
   int segments;
   int segsize;
   int segstart;
   int segend;
   int n;
 
-  loadavg = get_loadavg();
-  segments = ((int)(loadavg)) + 1;
+  segments = ((int)(gd->loadavg)) + 1;
   segsize = bar_breadth / segments;
 
   /* Clear the graph pixmap */
@@ -170,7 +181,7 @@ void draw_loadavg( GSysInfoData * gd, int barx, int bary, int bar_breadth, int b
 
   segstart = segend;
   segend = bar_breadth - 1;
-  segsize = (loadavg * (double)10 - ( segments - 1 ) * 10 ) * (segend - segstart + 1 ) / 10 + 1;
+  segsize = (gd->loadavg * (double)10 - ( segments - 1 ) * 10 ) * (segend - segstart + 1 ) / 10 + 1;
   if( segstart + segsize - 1 > segend ) {
       segsize = segend - segstart + 1;
   }
@@ -187,17 +198,19 @@ void draw_loadavg( GSysInfoData * gd, int barx, int bary, int bar_breadth, int b
 
 // barx, bary, bar_breadth, and bar_depth have already been corrected for the 
 // size of the border bevelling
-void draw_load( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_depth ) {
+void draw_load( GSysInfoData * gd, 
+		int barx, 
+		int bary, 
+		int bar_breadth, 
+		int bar_depth ) {
 
   int part1, part2, part3;
-  struct load load;
-
-  get_load ( &load );
+  struct load * curload = &(gd->curload);
 
   /* Calculate the bounds */
-  part1 = ( load.user * bar_breadth + 1 ) / load.total;
-  part2 = ( load.system * bar_breadth + 1 ) / load.total;
-  part3 = ( load.nice * bar_breadth + 1 ) / load.total;
+  part1 = ( curload->user * bar_breadth + 1 ) / curload->total;
+  part2 = ( curload->system * bar_breadth + 1 ) / curload->total;
+  part3 = ( curload->nice * bar_breadth + 1 ) / curload->total;
   
   /* Clear the graph pixmap */
   gdk_gc_set_foreground (gd->gc, & (AppColors[ BARGAUGEBG ].val) );
@@ -215,7 +228,11 @@ void draw_load( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_
 }
 
 
-void draw_mem( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_depth ) {
+void draw_mem( GSysInfoData * gd, 
+	       int barx, 
+	       int bary, 
+	       int bar_breadth, 
+	       int bar_depth ) {
     int normalmem, buffmem;
     struct meminfo * mem;
     int segstart;
@@ -244,7 +261,7 @@ void draw_mem( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_d
     gdk_draw_rectangle (gd->pixmap, gd->gc, TRUE, barx + segstart, bary, segsize, bar_depth );
 }
 
-void draw_swap( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_depth ) {
+int draw_swap( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_depth ) {
     unsigned long totalspace = 0;
     unsigned long totalfree = 0;
     unsigned long totalused;
@@ -267,30 +284,32 @@ void draw_swap( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_
     segsize = totalused * bar_breadth / totalspace + 1;
     gdk_gc_set_foreground (gd->gc, &(AppColors[ SWAPBAR ].val ) );
     gdk_draw_rectangle (gd->pixmap, gd->gc, TRUE, barx, bary, segsize, bar_depth );
+
+    return( totalused * 100 / totalspace );
 }
 
-/*
- * This function, gsysinfo_update, gets the new stats and updates the
- * pixmap.
- *
- */
+// get the current data (loadavg, load, mem, swap), and update each of the
+// four bar indicators
 gint
 gsysinfo_update (gpointer data)
 {
-  GSysInfoData * gd = data;
-  int cury;
-  int n;
+  GSysInfoData *    gd = data;
+  int		    cury;
+  int		    n;
+
+  get_load ( &(gd->curload) );
+  gd->loadavg = get_loadavg();
 
   cury = 0; 
 
   if( gd->loadavg_on ) {
-      draw_loadavg( gd, 2, cury + 2, gd->bar_breadth - 4, gd->bar_depth - 4 );
+      draw_loadavg( gd, 0, cury, gd->bar_breadth, gd->bar_depth );
       cury += gd->bar_depth;
   }
 
 
   if( gd->load_on ) {
-      draw_load( gd, 2, cury + 2, gd->bar_breadth - 4, gd->bar_depth - 4 );
+      draw_load( gd, 0, cury, gd->bar_breadth, gd->bar_depth );
       cury += gd->bar_depth;
   }
 
@@ -300,14 +319,15 @@ gsysinfo_update (gpointer data)
   }
 
   if( gd->mem_on ) {
-      draw_mem( gd, 2, cury + 2, gd->bar_breadth - 4, gd->bar_depth - 4 );
+      draw_mem( gd, 0, cury, gd->bar_breadth, gd->bar_depth );
       cury += gd->bar_depth;
   }
 
   if( gd->swap_on ) {
-      draw_swap( gd, 2, cury + 2, gd->bar_breadth - 4, gd->bar_depth - 4 );
+      gd->swap = draw_swap( gd, 0, cury, gd->bar_breadth, gd->bar_depth );
   }
 
+  update_tooltip( gd );
 
   /* Update the display. */
   expose_handler (gd->loadavg_area, NULL, gd);
@@ -316,6 +336,52 @@ gsysinfo_update (gpointer data)
 } /* gsysinfo_update */
 
 
+
+update_tooltip( GSysInfoData *    gd )
+{
+  struct load *	    curload = &(gd->curload);
+  struct meminfo *  mem = &(gd->memstats[0]);
+
+  int		    user, system, nice, idle;
+  int		    buffmem, normalmem, freemem;
+  int		    normalperc, buffperc, freeperc;
+
+  user = curload->user * 100 / curload->total;
+  system = curload->system * 100 / curload->total;
+  nice = curload->nice * 100 / curload->total;
+  idle = 100 - user - system - nice;
+
+  buffmem = mem->cache + mem->buffers;
+  normalmem = mem->total - mem->free - buffmem;
+
+  normalperc = normalmem * 100 / mem->total;
+  buffperc = buffmem * 100 / mem->total;
+  freeperc = mem->free * 100 / mem->total;
+
+  normalmem /= 1024;
+  buffmem /= 1024;
+  freemem = mem->free / 1024;
+
+
+  if( gd->tooltip_update ) {
+      sprintf( gd->tooltip, 
+	       "Load: %.2f     \n"
+	       "User: %d%%\nKernel: %d%%\nNice: %d%%\nIdle: %d%%\n"
+	       "Used Mem: %d MB (%d%%)\n"
+	       "Buffers/Cache: %d MB (%d%%)\n"
+	       "Free: %d MB (%d%%)\n"
+	       "Swap: %d%%", 
+	       gd->loadavg, 
+	       user, system, nice, idle, 
+	       normalmem, normalperc,
+	       buffmem, buffperc,
+	       freemem, freeperc,
+	       gd->swap );
+      gtk_tooltips_set_tip( gd->tooltips, gd->applet, gd->tooltip, NULL );
+  }
+}
+
+
 /*
  * This function is called whenever a portion of the
  * applet window has been exposed and needs to be redrawn.  In this
@@ -391,38 +457,56 @@ orient_handler (GtkWidget * w, PanelOrientType o, gpointer data)
   return FALSE;
 } /* orient_handler */
 
+
+gint
+pointer_handler (GtkWidget * w, GdkEvent *event, gpointer data)
+{
+    GSysInfoData * gd = data;
+    GdkEventType type;
+  
+    type = event->type;
+    if( type == GDK_ENTER_NOTIFY ) {
+	// don't update 
+	gd->tooltip_update = FALSE;
+    } else if( type == GDK_LEAVE_NOTIFY ) {
+	gd->tooltip_update = TRUE;
+    }
+    return FALSE;
+} 
+
 void configure_layout( GSysInfoData * gd ) {
   int cury;
 
   
   cury = 0; 
   if( gd->loadavg_on ) {
-      gtk_fixed_move( gd->fixed, gd->loadavg_area, 0, cury );
-      gtk_widget_show( gd->loadavg_area );
+      //gtk_fixed_move( gd->fixed, gd->loadavg_area, 0, cury );
+      gtk_fixed_move( gd->fixed, gd->loadavg_frame, 0, cury );
+      gtk_widget_show( gd->loadavg_frame );
       cury += gd->bar_depth + gd->gap_depth;
   } else {
-      gtk_widget_hide( gd->loadavg_area );
+      gtk_widget_hide( gd->loadavg_frame );
   }
   if( gd->load_on ) {
-      gtk_fixed_move( gd->fixed, gd->load_area, 0, cury );
-      gtk_widget_show( gd->load_area );
+      gtk_fixed_move( gd->fixed, gd->load_frame, 0, cury );
+      gtk_widget_show( gd->load_frame );
       cury += gd->bar_depth + gd->gap_depth;
   } else {
-      gtk_widget_hide( gd->load_area );
+      gtk_widget_hide( gd->load_frame );
   }
   if( gd->mem_on ) {
-      gtk_fixed_move( gd->fixed, gd->mem_area, 0, cury );
-      gtk_widget_show( gd->mem_area );
+      gtk_fixed_move( gd->fixed, gd->mem_frame, 0, cury );
+      gtk_widget_show( gd->mem_frame );
       cury += gd->bar_depth + gd->gap_depth;
   } else {
-      gtk_widget_hide( gd->mem_area );
+      gtk_widget_hide( gd->mem_frame );
   }
   if( gd->swap_on ) {
-      gtk_fixed_move( gd->fixed, gd->swap_area, 0, cury );
-      gtk_widget_show( gd->swap_area );
+      gtk_fixed_move( gd->fixed, gd->swap_frame, 0, cury );
+      gtk_widget_show( gd->swap_frame );
       cury += gd->bar_depth + gd->gap_depth;
   } else {
-      gtk_widget_hide( gd->swap_area );
+      gtk_widget_hide( gd->swap_frame );
   }
 }
 
@@ -436,7 +520,6 @@ applet_start_new_applet (const gchar *goad_id, const char **params,
 /* This is the function that actually creates the display widgets */
 GtkWidget *
 make_new_gsysinfo_applet (const gchar *goad_id) {
-  GSysInfoData * gd;
   gchar * param = "gsysinfo_applet";
 
   gd = g_new0 (GSysInfoData, 1);
@@ -463,81 +546,112 @@ make_new_gsysinfo_applet (const gchar *goad_id) {
       gsysinfo_session_load (APPLET_WIDGET (gd->applet)->privcfgpath, gd);
     }
 
-  /*
-   * area is the drawing area into which each gauge gets drawn
-   */
-  gd->fixed = (GtkFixed *) gtk_fixed_new();
-  gd->loadavg_area = gtk_drawing_area_new ();
-  gd->load_area = gtk_drawing_area_new ();
-  gd->mem_area = gtk_drawing_area_new ();
-  gd->swap_area = gtk_drawing_area_new ();
+    // create container to hold the bars
+    gd->fixed = (GtkFixed *) gtk_fixed_new();
 
-  gtk_widget_set_usize (gd->loadavg_area, gd->bar_breadth, gd->bar_depth ); 
-  gtk_widget_set_usize (gd->load_area, gd->bar_breadth, gd->bar_depth );
-  gtk_widget_set_usize (gd->mem_area, gd->bar_breadth, gd->bar_depth );
-  gtk_widget_set_usize (gd->swap_area, gd->bar_breadth, gd->bar_depth );
+    // create a frame for each bar gauge
+    gd->loadavg_frame = gtk_frame_new( NULL );
+    gd->load_frame = gtk_frame_new( NULL );
+    gd->mem_frame = gtk_frame_new( NULL );
+    gd->swap_frame = gtk_frame_new( NULL );
 
-  gtk_fixed_put( gd->fixed, gd->loadavg_area, 0, 0 );
-  gtk_fixed_put( gd->fixed, gd->load_area, 0, 0 );
-  gtk_fixed_put( gd->fixed, gd->mem_area, 0, 0 );
-  gtk_fixed_put( gd->fixed, gd->swap_area, 0, 0 );
+    // make each frame have a shadow
+    gtk_frame_set_shadow_type( GTK_FRAME( gd->loadavg_frame ), GTK_SHADOW_IN );
+    gtk_frame_set_shadow_type( GTK_FRAME( gd->load_frame ), GTK_SHADOW_IN );
+    gtk_frame_set_shadow_type( GTK_FRAME( gd->mem_frame ), GTK_SHADOW_IN );
+    gtk_frame_set_shadow_type( GTK_FRAME( gd->swap_frame ), GTK_SHADOW_IN );
 
-  /* Set up the event callbacks for the area. */
-  gtk_signal_connect (GTK_OBJECT (gd->loadavg_area), "expose_event",
-		      (GtkSignalFunc)expose_handler, gd);
-  gtk_signal_connect (GTK_OBJECT (gd->load_area), "expose_event",
-		      (GtkSignalFunc)expose_handler, gd);
-  gtk_signal_connect (GTK_OBJECT (gd->mem_area), "expose_event",
-		      (GtkSignalFunc)expose_handler, gd);
-  gtk_signal_connect (GTK_OBJECT (gd->swap_area), "expose_event",
-		      (GtkSignalFunc)expose_handler, gd);
+    // create drawing areas
+    gd->loadavg_area = gtk_drawing_area_new ();
+    gd->load_area = gtk_drawing_area_new ();
+    gd->mem_area = gtk_drawing_area_new ();
+    gd->swap_area = gtk_drawing_area_new ();
 
-  gtk_widget_set_events (gd->loadavg_area, GDK_EXPOSURE_MASK );
-  gtk_widget_set_events (gd->load_area, GDK_EXPOSURE_MASK );
-  gtk_widget_set_events (gd->mem_area, GDK_EXPOSURE_MASK );
-  gtk_widget_set_events (gd->swap_area, GDK_EXPOSURE_MASK );
+    // put one drawing area inside each frame
+    gtk_container_add( GTK_CONTAINER( gd->loadavg_frame ), gd->loadavg_area );
+    gtk_container_add( GTK_CONTAINER( gd->load_frame ), gd->load_area );
+    gtk_container_add( GTK_CONTAINER( gd->mem_frame ), gd->mem_area );
+    gtk_container_add( GTK_CONTAINER( gd->swap_frame ), gd->swap_area );
 
-  /* This will let us know when the panel changes orientation */
-  gtk_signal_connect (GTK_OBJECT (gd->applet), "change_orient",
-		      GTK_SIGNAL_FUNC (orient_handler),
-		      gd);
+    // set sizes of the drawing areas
+    gtk_widget_set_usize (gd->loadavg_area, gd->bar_breadth, gd->bar_depth ); 
+    gtk_widget_set_usize (gd->load_area, gd->bar_breadth, gd->bar_depth );
+    gtk_widget_set_usize (gd->mem_area, gd->bar_breadth, gd->bar_depth );
+    gtk_widget_set_usize (gd->swap_area, gd->bar_breadth, gd->bar_depth );
 
+    // place the frames in the fixed container
+    //gtk_fixed_put( gd->fixed, gd->loadavg_area, 0, 0 );
+    gtk_fixed_put( gd->fixed, gd->loadavg_frame, 0, 0 );
+    gtk_fixed_put( gd->fixed, gd->load_frame, 0, 0 );
+    gtk_fixed_put( gd->fixed, gd->mem_frame, 0, 0 );
+    gtk_fixed_put( gd->fixed, gd->swap_frame, 0, 0 );
 
-  applet_widget_add (APPLET_WIDGET (gd->applet), GTK_WIDGET( gd->fixed ) );
+    /* Set up the event callbacks for the area. */
+    gtk_signal_connect (GTK_OBJECT (gd->loadavg_area), "expose_event",
+		        (GtkSignalFunc)expose_handler, gd);
+    gtk_signal_connect (GTK_OBJECT (gd->load_area), "expose_event",
+		        (GtkSignalFunc)expose_handler, gd);
+    gtk_signal_connect (GTK_OBJECT (gd->mem_area), "expose_event",
+		        (GtkSignalFunc)expose_handler, gd);
+    gtk_signal_connect (GTK_OBJECT (gd->swap_area), "expose_event",
+		        (GtkSignalFunc)expose_handler, gd);
+  
+    gtk_widget_set_events (gd->loadavg_area, GDK_EXPOSURE_MASK );
+    gtk_widget_set_events (gd->load_area, GDK_EXPOSURE_MASK );
+    gtk_widget_set_events (gd->mem_area, GDK_EXPOSURE_MASK );
+    gtk_widget_set_events (gd->swap_area, GDK_EXPOSURE_MASK );
+  
+    /* This will let us know when the panel changes orientation */
+    gtk_signal_connect (GTK_OBJECT (gd->applet), "change_orient",
+		        GTK_SIGNAL_FUNC (orient_handler),
+		        gd);
+  
+    gd->tooltip_update = TRUE;
+    gtk_signal_connect (GTK_OBJECT (gd->applet), "enter_notify_event",
+		        GTK_SIGNAL_FUNC (pointer_handler),
+		        gd);
+  
+    gtk_signal_connect (GTK_OBJECT (gd->applet), "leave_notify_event",
+		        GTK_SIGNAL_FUNC (pointer_handler),
+		        gd);
+  
+    applet_widget_add (APPLET_WIDGET (gd->applet), GTK_WIDGET( gd->fixed ) );
+  
+    gtk_signal_connect (GTK_OBJECT (gd->applet), "save_session",
+		        GTK_SIGNAL_FUNC (gsysinfo_session_save),
+		        gd);
 
-  gtk_signal_connect (GTK_OBJECT (gd->applet), "save_session",
-		      GTK_SIGNAL_FUNC (gsysinfo_session_save),
-		      gd);
-
-  applet_widget_register_stock_callback (APPLET_WIDGET (gd->applet),
-					 "about",
-					 GNOME_STOCK_MENU_ABOUT,
-					 _("About..."),
-					 about_cb,
-					 gd);
-
-  applet_widget_register_stock_callback (APPLET_WIDGET (gd->applet),
-					 "properties",
-					 GNOME_STOCK_MENU_PROP,
-					 ("Properties..."),
-					 properties_window,
-					 gd);
-
-  gtk_widget_show_all (gd->applet);
-
-  configure_layout( gd );
-  gsysinfo_set_size (gd);
-
-  gsysinfo_create_gc (gd);
-  gsysinfo_setup_colors (gd);
-
-  /* Nothing is drawn until this is set. */
-  gd->setup = TRUE;
-
-  /* Will schedule a timeout */
-  set_timeout( gd );
-
-  return gd->applet;
+    applet_widget_register_stock_callback (APPLET_WIDGET (gd->applet),
+					   "about",
+					   GNOME_STOCK_MENU_ABOUT,
+					   _("About..."),
+					   about_cb,
+					   gd);
+  
+    applet_widget_register_stock_callback (APPLET_WIDGET (gd->applet),
+					   "properties",
+					   GNOME_STOCK_MENU_PROP,
+					   ("Properties..."),
+					   properties_window,
+					   gd);
+  
+    gtk_widget_show_all (gd->applet);
+  
+    configure_layout( gd );
+    gsysinfo_setup_colors (gd);
+    gsysinfo_set_size (gd);
+  
+    gsysinfo_create_gc (gd);
+  
+    gd->tooltips = gtk_tooltips_new();
+  
+    /* Nothing is drawn until this is set. */
+    gd->setup = TRUE;
+  
+    /* Will schedule a timeout */
+    set_timeout( gd );
+  
+    return gd->applet;
 } /* make_new_gsysinfo_applet */
 
 void set_timeout (GSysInfoData *gd) { 
@@ -636,9 +750,9 @@ gsysinfo_set_size (GSysInfoData * gd)
     gdk_image_destroy (gd->image);
   }
 
-  for( n = 0; n < gd->numbars; n++ ) {
-      draw_border( gd, 0, n * gd->bar_depth, gd->bar_breadth - 1, ( n + 1 ) * gd->bar_depth - 1 );
-  }
+  //for( n = 0; n < gd->numbars; n++ ) {
+      //draw_border( gd, 0, n * gd->bar_depth, gd->bar_breadth - 1, ( n + 1 ) * gd->bar_depth - 1 );
+  //}
 
 } /* gsysinfo_set_size */
 
@@ -655,7 +769,6 @@ void
 gsysinfo_setup_colors(GSysInfoData * gd)
 {
   GdkColormap *colormap;
-  gint strl, strr, strw, stra, strd;
   int	n;
 
   /*
@@ -669,6 +782,5 @@ gsysinfo_setup_colors(GSysInfoData * gd)
       gdk_color_parse( AppColors[ n ].stringval, &( AppColors[n].val ) );
       gdk_color_alloc( colormap, &( AppColors[n].val ) );
   }
-
 } 
 
