@@ -25,12 +25,13 @@
 
 /* I dunno what PACKAGE means... */
 #define PACKAGE "gnome-core"
-#define VERSION "0.9"
+#define VERSION "1.0"
 
 #include <applet-widget.h>
 #include "sysinfo.h"
 
 #define MAX_SWAP_FILES		    8
+#define max_rgb_str_size	    8
 
 typedef struct GSysInfoData {
   GtkWidget *applet;
@@ -49,16 +50,30 @@ typedef struct GSysInfoData {
   gint timeout_t;
 
   /* Widgets n stuff... */
+
+  // drawing areas
   GtkWidget *loadavg_area;
   GtkWidget *load_area;
   GtkWidget *mem_area;
   GtkWidget *swap_area;
+
+  // frames (for the bevelling)
+  GtkWidget *loadavg_frame;
+  GtkWidget *load_frame;
+  GtkWidget *mem_frame;
+  GtkWidget *swap_frame;
+
+  // other stuff
   GdkPixmap *pixmap;
   GdkImage *image;
   GdkGC *gc;
 
   GtkWidget *about_box;
 
+  GtkTooltips * tooltips;
+  char		tooltip[ 255 ];
+  gboolean	tooltip_update;
+
   /*
    *
    * For the  "Properties" window ...
@@ -82,7 +97,10 @@ typedef struct GSysInfoData {
   GnomeColorPicker *background_sel;
 
   struct meminfo memstats[ MAX_SWAP_FILES ];
+  struct load curload;
+  double loadavg;
   int numswapfiles;
+  int swap;
 
 } GSysInfoData;
 
@@ -130,8 +148,12 @@ void configure_layout( GSysInfoData * gd );
 
 typedef struct Color {
     const char *    name;
-    gchar	    stringval[30];
+    const char *    propname;
+    gchar	    stringval[max_rgb_str_size];
+    gchar	    tempval[max_rgb_str_size];
     GdkColor	    val;
+    GtkWidget *	    widget;	    
+    GtkWidget *	    label;
 } a_color;
 
 enum Colors {
@@ -143,18 +165,19 @@ enum Colors {
     LOADAVGBAR5,
     LOADAVGBAR6,
     LOADAVGBAR7,
+    LOADAVGBAR8,
+    LOADAVGBAR9,
     LOADBAR,
     LOADBAR1,
     LOADBAR2,
     MEMBAR0,
     MEMBAR1,
     SWAPBAR,
-    SWAPBAR1,
-    SWAPBAR2,
     BARGAUGEBG,
     NUM_COLORS 
 };
 
 extern a_color AppColors[NUM_COLORS];
+extern GSysInfoData * gd;
 
 #endif /* GNOMESYSINFO_H */
