@@ -37,19 +37,30 @@
 void
 gsysinfo_session_load(gchar * cfgpath, GSysInfoData * gd)
 {
+    gchar * tempstring;
+    gchar   propname[ 100 ];
+    int		    n;
 
-  /* We specify that we want the properties for this applet ... */
-  gnome_config_push_prefix (cfgpath);
+    /* We specify that we want the properties for this applet ... */
+    gnome_config_push_prefix (cfgpath);
 
-  gd->load_on = gnome_config_get_bool_with_default( "gsysinfo/load_on=true", NULL );
-  gd->loadavg_on = gnome_config_get_bool_with_default( "gsysinfo/loadavg_on=true", NULL );
-  gd->mem_on = gnome_config_get_bool_with_default( "gsysinfo/mem_on=true", NULL );
-  gd->swap_on = gnome_config_get_bool_with_default( "gsysinfo/swap_on=true", NULL );
+    gd->load_on = gnome_config_get_bool_with_default( "gsysinfo/load_on=true", NULL );
+    gd->loadavg_on = gnome_config_get_bool_with_default( "gsysinfo/loadavg_on=true", NULL );
+    gd->mem_on = gnome_config_get_bool_with_default( "gsysinfo/mem_on=true", NULL );
+    gd->swap_on = gnome_config_get_bool_with_default( "gsysinfo/swap_on=true", NULL );
 
-  gd->timeout_t = gnome_config_get_int_with_default( "gsysinfo/delay=1000", NULL );
+    gd->timeout_t = gnome_config_get_int_with_default( "gsysinfo/delay=1000", NULL );
 
+    for( n = 0; n < NUM_COLORS; n++ ) {
+	strcpy( propname, "gsysinfo/" );
+	strcat( propname, AppColors[n].propname );
+	tempstring = gnome_config_get_string( propname );
+	if( tempstring != NULL ) {
+	    strncpy( AppColors[n].stringval, tempstring, max_rgb_str_size );
+	}
+    }
 
-  gnome_config_pop_prefix ();
+    gnome_config_pop_prefix ();
 } /* gsysinfo_session_load */
 
 int
@@ -58,23 +69,31 @@ gsysinfo_session_save(GtkWidget * w,
 		     const char * globcfgpath,
 		     gpointer data)
 {
-  GSysInfoData * gd = data;
+    GSysInfoData *  gd = data;
+    gchar	    propname[ 100 ];
+    int		    n;
 
-  gnome_config_push_prefix (privcfgpath);
+    gnome_config_push_prefix (privcfgpath);
 
-  gnome_config_set_bool( "gsysinfo/load_on", gd->load_on );
-  gnome_config_set_bool( "gsysinfo/loadavg_on", gd->loadavg_on );
-  gnome_config_set_bool( "gsysinfo/mem_on", gd->mem_on );
-  gnome_config_set_bool( "gsysinfo/swap_on", gd->swap_on );
+    gnome_config_set_bool( "gsysinfo/load_on", gd->load_on );
+    gnome_config_set_bool( "gsysinfo/loadavg_on", gd->loadavg_on );
+    gnome_config_set_bool( "gsysinfo/mem_on", gd->mem_on );
+    gnome_config_set_bool( "gsysinfo/swap_on", gd->swap_on );
 
-  gnome_config_set_int( "gsysinfo/delay", gd->timeout_t );
+    gnome_config_set_int( "gsysinfo/delay", gd->timeout_t );
 
-  gnome_config_pop_prefix ();
+    for( n = 0; n < NUM_COLORS; n++ ) {
+	strcpy( propname, "gsysinfo/" );
+	strcat( propname, AppColors[n].propname );
+	gnome_config_set_string ( propname, AppColors[n].stringval );
+    }
 
-  gnome_config_sync ();
-  gnome_config_drop_all ();
+    gnome_config_pop_prefix ();
 
-  return FALSE;
+    gnome_config_sync ();
+    gnome_config_drop_all ();
+  
+    return FALSE;
 } /* gsysinfo_session_save */
 
 void
@@ -85,9 +104,9 @@ gsysinfo_session_defaults(GSysInfoData * gd)
   gd->breadth = atoi (MERLIN_CLOCK_DEFAULT_BREADTH);
   gd->timeout_t = 1000;
   gd->timeout = 0;
-  gd->bar_breadth = 48;
-  gd->bar_depth = 10;
-  gd->gap_depth = 3;
+  gd->bar_breadth = 44;
+  gd->bar_depth = 6;
+  gd->gap_depth = 5;
   
   gd->load_on = 1;
   gd->loadavg_on = 1;
